<?php

namespace FiloBlu\ExtTargetRule\Controller\Products;

use Magento\Framework\App\Action\Action;
use Magento\Framework\App\Action\Context;
use FiloBlu\ExtTargetRule\Helper\Data;
use Magento\Framework\View\LayoutInterface;
use Magento\Framework\Controller\ResultFactory;
use Magento\Framework\Controller\Result\JsonFactory;
use Magento\Framework\Registry;


class Upsell extends Action
{
    /**
     * @var Context
     */
    protected $context;
    /**
     * @var Data
     */
    protected $helper;
    /**
     * @var LayoutInterface
     */
    protected $layout;
    /**
     * @var JsonFactory
     */
    protected $jsonFactory;
    /**
     * @var Registry
     */
    protected $registry;

    /**
     * @param Context $context
     * @param Data $helper
     * @param LayoutInterface $layout
     * @param JsonFactory $jsonFactory
     * @param Registry $registry
     */
    public function __construct(
        Context $context,
        Data $helper,
        LayoutInterface $layout,
        JsonFactory $jsonFactory,
        Registry $registry
    )
    {
        parent::__construct($context);
        $this->context = $context;
        $this->helper = $helper;
        $this->layout = $layout;
        $this->layout->getUpdate()->addHandle('default');
        $this->jsonFactory = $jsonFactory;
        $this->registry = $registry;
    }

    /**
     * @return false|\Magento\Framework\App\ResponseInterface|\Magento\Framework\Controller\Result\Json|\Magento\Framework\Controller\ResultInterface
     */
    public function execute()
    {

        $productId = (int) $this->getRequest()->getParam('id');
        $product = $this->helper->loadProduct($productId);
        if (!$product) {
            return false;
        }

        $this->registry->register('current_product', $product);
        $this->registry->register('product', $product);

        /** @var \Magento\Framework\Controller\Result\Json $resultJson */
        $resultJson = $this->jsonFactory->create();


        /** @var \Magento\Framework\View\Layout $layout */
        $layout = $this->_view->getLayout();
        $block = $layout->createBlock(\FiloBlu\ExtTargetRule\Block\TargetRule\Catalog\Product\ProductList\Upsell::class);
        $block->setTemplate('Magento_Catalog::product/list/items.phtml')
            ->setType('upsell-rule')
            ->setTtl(0);
        /** @var array $response */
        $response = [
            'content' => $block->toHtml()
        ];


        return $resultJson->setData($response);
    }
}